@@ -93,7 +93,7 @@ impl DBPool {
                     .min_connections(opt.min_connections)
                     .idle_timeout(opt.idle_timeout)
                     .test_before_acquire(opt.test_before_acquire);
-                let p = build.connect_with(driver.mysql.clone().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?).await?;
+                let p = build.connect_with(driver.mysql.clone().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?).await?;
                 pool.mysql = Some(p);
                 return Ok(pool);
             }
@@ -107,7 +107,7 @@ impl DBPool {
                     .min_connections(opt.min_connections)
                     .idle_timeout(opt.idle_timeout)
                     .test_before_acquire(opt.test_before_acquire);
-                let p = build.connect_with(driver.postgres.clone().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?).await?;
+                let p = build.connect_with(driver.postgres.clone().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?).await?;
                 pool.postgres = Some(p);
                 return Ok(pool);
             }
@@ -121,7 +121,7 @@ impl DBPool {
                     .min_connections(opt.min_connections)
                     .idle_timeout(opt.idle_timeout)
                     .test_before_acquire(opt.test_before_acquire);
-                let p = build.connect_with(driver.sqlite.clone().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?).await?;
+                let p = build.connect_with(driver.sqlite.clone().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?).await?;
                 pool.sqlite = Some(p);
                 return Ok(pool);
             }
@@ -135,7 +135,7 @@ impl DBPool {
                     .min_connections(opt.min_connections)
                     .idle_timeout(opt.idle_timeout)
                     .test_before_acquire(opt.test_before_acquire);
-                let p = build.connect_with(driver.mssql.clone().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?).await?;
+                let p = build.connect_with(driver.mssql.clone().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?).await?;
                 pool.mssql = Some(p);
                 return Ok(pool);
             }
@@ -223,7 +223,7 @@ impl DBPool {
                 return Ok(DBPoolConn {
                     driver_type: DriverType::Mysql,
                     #[cfg(feature = "mysql")]
-                    mysql: Some(self.mysql.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.acquire().await?),
+                    mysql: Some(self.mysql.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.acquire().await?),
                     #[cfg(feature = "postgres")]
                     postgres: None,
                     #[cfg(feature = "sqlite")]
@@ -239,7 +239,7 @@ impl DBPool {
                     #[cfg(feature = "mysql")]
                     mysql: None,
                     #[cfg(feature = "postgres")]
-                    postgres: Some(self.postgres.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.acquire().await?),
+                    postgres: Some(self.postgres.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.acquire().await?),
                     #[cfg(feature = "sqlite")]
                     sqlite: None,
                     #[cfg(feature = "mssql")]
@@ -255,7 +255,7 @@ impl DBPool {
                     #[cfg(feature = "postgres")]
                     postgres: None,
                     #[cfg(feature = "sqlite")]
-                    sqlite: Some(self.sqlite.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.acquire().await?),
+                    sqlite: Some(self.sqlite.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.acquire().await?),
                     #[cfg(feature = "mssql")]
                     mssql: None,
                 });
@@ -271,7 +271,7 @@ impl DBPool {
                     #[cfg(feature = "sqlite")]
                     sqlite: None,
                     #[cfg(feature = "mssql")]
-                    mssql: Some(self.mssql.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.acquire().await?),
+                    mssql: Some(self.mssql.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.acquire().await?),
                 });
             }
 
@@ -291,14 +291,14 @@ impl DBPool {
             }
             #[cfg(feature = "mysql")]
             &DriverType::Mysql => {
-                let conn = self.mysql.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.try_acquire();
+                let conn = self.mysql.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.try_acquire();
                 if conn.is_none() {
                     return Ok(None);
                 }
                 return Ok(Some(DBPoolConn {
                     driver_type: self.driver_type,
                     #[cfg(feature = "mysql")]
-                    mysql: Some(conn.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?),
+                    mysql: Some(conn.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?),
                     #[cfg(feature = "postgres")]
                     postgres: None,
                     #[cfg(feature = "sqlite")]
@@ -309,7 +309,7 @@ impl DBPool {
             }
             #[cfg(feature = "postgres")]
             &DriverType::Postgres => {
-                let conn = self.postgres.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.try_acquire();
+                let conn = self.postgres.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.try_acquire();
                 if conn.is_none() {
                     return Ok(None);
                 }
@@ -318,7 +318,7 @@ impl DBPool {
                     #[cfg(feature = "mysql")]
                     mysql: None,
                     #[cfg(feature = "postgres")]
-                    postgres: Some(conn.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?),
+                    postgres: Some(conn.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?),
                     #[cfg(feature = "sqlite")]
                     sqlite: None,
                     #[cfg(feature = "mssql")]
@@ -327,7 +327,7 @@ impl DBPool {
             }
             #[cfg(feature = "sqlite")]
             &DriverType::Sqlite => {
-                let conn = self.sqlite.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.try_acquire();
+                let conn = self.sqlite.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.try_acquire();
                 if conn.is_none() {
                     return Ok(None);
                 }
@@ -338,14 +338,14 @@ impl DBPool {
                     #[cfg(feature = "postgres")]
                     postgres: None,
                     #[cfg(feature = "sqlite")]
-                    sqlite: Some(conn.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?),
+                    sqlite: Some(conn.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?),
                     #[cfg(feature = "mssql")]
                     mssql: None,
                 }));
             }
             #[cfg(feature = "mssql")]
             &DriverType::Mssql => {
-                let conn = self.mssql.as_ref().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.try_acquire();
+                let conn = self.mssql.as_ref().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.try_acquire();
                 if conn.is_none() {
                     return Ok(None);
                 }
@@ -358,7 +358,7 @@ impl DBPool {
                     #[cfg(feature = "sqlite")]
                     sqlite: None,
                     #[cfg(feature = "mssql")]
-                    mssql: Some(conn.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?),
+                    mssql: Some(conn.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?),
                 }));
             }
 
@@ -588,7 +588,7 @@ impl<'q> DBQuery<'q> {
             }
             #[cfg(feature = "mysql")]
             &DriverType::Mysql => {
-                let mut q = self.mysql.take().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?;
+                let mut q = self.mysql.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
                         q = q.bind(Some(s.to_owned()));
@@ -598,11 +598,11 @@ impl<'q> DBQuery<'q> {
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
-                            q = q.bind(n.as_f64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_f64().unwrap_or_default());
                         } else if n.is_u64() {
-                            q = q.bind(n.as_u64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_u64().unwrap_or_default());
                         } else if n.is_i64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_i64().unwrap_or_default());
                         }
                     }
                     serde_json::Value::Bool(b) => {
@@ -616,7 +616,7 @@ impl<'q> DBQuery<'q> {
             }
             #[cfg(feature = "postgres")]
             &DriverType::Postgres => {
-                let mut q = self.postgres.take().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?;
+                let mut q = self.postgres.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
                         q = q.bind(Some(s.to_owned()));
@@ -626,11 +626,11 @@ impl<'q> DBQuery<'q> {
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
-                            q = q.bind(n.as_f64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
-                        } else if n.is_i64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_f64().unwrap_or_default());
                         } else if n.is_u64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_i64().unwrap_or_default());
+                        } else if n.is_i64() {
+                            q = q.bind(n.as_i64().unwrap_or_default());
                         }
                     }
                     serde_json::Value::Bool(b) => {
@@ -644,7 +644,7 @@ impl<'q> DBQuery<'q> {
             }
             #[cfg(feature = "sqlite")]
             &DriverType::Sqlite => {
-                let mut q = self.sqlite.take().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?;
+                let mut q = self.sqlite.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
                         q = q.bind(Some(s.to_owned()));
@@ -654,11 +654,11 @@ impl<'q> DBQuery<'q> {
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
-                            q = q.bind(n.as_f64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
-                        } else if n.is_i64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_f64().unwrap_or_default());
                         } else if n.is_u64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_i64().unwrap_or_default());
+                        } else if n.is_i64() {
+                            q = q.bind(n.as_i64().unwrap_or_default());
                         }
                     }
                     serde_json::Value::Bool(b) => {
@@ -672,7 +672,7 @@ impl<'q> DBQuery<'q> {
             }
             #[cfg(feature = "mssql")]
             &DriverType::Mssql => {
-                let mut q = self.mssql.take().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?;
+                let mut q = self.mssql.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
                         q = q.bind(Some(s.to_owned()));
@@ -682,11 +682,11 @@ impl<'q> DBQuery<'q> {
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
-                            q = q.bind(n.as_f64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
-                        } else if n.is_i64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_f64().unwrap_or_default());
                         } else if n.is_u64() {
-                            q = q.bind(n.as_i64().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?);
+                            q = q.bind(n.as_i64().unwrap_or_default());
+                        } else if n.is_i64() {
+                            q = q.bind(n.as_i64().unwrap_or_default());
                         }
                     }
                     serde_json::Value::Bool(b) => {
@@ -769,8 +769,8 @@ impl DBPoolConn {
             #[cfg(feature = "mysql")]
             &DriverType::Mysql => {
                 let async_stream: Vec<MySqlRow> =
-                    self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.fetch_all(sql).await?;
-                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                    self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.fetch_all(sql).await?;
+                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -778,16 +778,16 @@ impl DBPoolConn {
             #[cfg(feature = "postgres")]
             &DriverType::Postgres => {
                 let async_stream: Vec<PgRow> =
-                    self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.fetch_all(sql).await?;
-                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                    self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.fetch_all(sql).await?;
+                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
             }
             #[cfg(feature = "sqlite")]
             &DriverType::Sqlite => {
-                let data: Vec<SqliteRow> = self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.fetch_all(sql).await?;
-                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                let data: Vec<SqliteRow> = self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.fetch_all(sql).await?;
+                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -795,8 +795,8 @@ impl DBPoolConn {
             #[cfg(feature = "mssql")]
             &DriverType::Mssql => {
                 let async_stream: Vec<MssqlRow> =
-                    self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.fetch_all(sql).await?;
-                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                    self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.fetch_all(sql).await?;
+                let json_array = async_stream.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -815,22 +815,22 @@ impl DBPoolConn {
             }
             #[cfg(feature = "mysql")]
             &DriverType::Mysql => {
-                let data: MySqlQueryResult = self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.execute(sql).await?;
+                let data: MySqlQueryResult = self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.execute(sql).await?;
                 return Ok(DBExecResult::from(data));
             }
             #[cfg(feature = "postgres")]
             &DriverType::Postgres => {
-                let data: PgQueryResult = self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.execute(sql).await?;
+                let data: PgQueryResult = self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.execute(sql).await?;
                 return Ok(DBExecResult::from(data));
             }
             #[cfg(feature = "sqlite")]
             &DriverType::Sqlite => {
-                let data: SqliteQueryResult = self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.execute(sql).await?;
+                let data: SqliteQueryResult = self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.execute(sql).await?;
                 return Ok(DBExecResult::from(data));
             }
             #[cfg(feature = "mssql")]
             &DriverType::Mssql => {
-                let data: MssqlQueryResult = self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.execute(sql).await?;
+                let data: MssqlQueryResult = self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.execute(sql).await?;
                 return Ok(DBExecResult::from(data));
             }
             _ => {
@@ -853,10 +853,10 @@ impl DBPoolConn {
                 let data: Vec<MySqlRow> = self
                     .mysql
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .fetch_all(sql.mysql.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .fetch_all(sql.mysql.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
-                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -866,10 +866,10 @@ impl DBPoolConn {
                 let data: Vec<PgRow> = self
                     .postgres
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .fetch_all(sql.postgres.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .fetch_all(sql.postgres.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
-                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -879,10 +879,10 @@ impl DBPoolConn {
                 let data: Vec<SqliteRow> = self
                     .sqlite
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .fetch_all(sql.sqlite.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .fetch_all(sql.sqlite.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
-                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -892,10 +892,10 @@ impl DBPoolConn {
                 let data: Vec<MssqlRow> = self
                     .mssql
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .fetch_all(sql.mssql.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .fetch_all(sql.mssql.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
-                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.to_owned();
+                let json_array = data.try_to_json()?.as_array().ok_or_else(|| Error::from("[rbatis-core] try_to_json is not array!"))?.to_owned();
                 let return_len = json_array.len();
                 let result = json_decode::<T>(json_array)?;
                 Ok((result, return_len))
@@ -917,8 +917,8 @@ impl DBPoolConn {
                 let result: MySqlQueryResult = self
                     .mysql
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .execute(sql.mysql.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .execute(sql.mysql.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
                 return Ok(DBExecResult::from(result));
             }
@@ -927,8 +927,8 @@ impl DBPoolConn {
                 let data: PgQueryResult = self
                     .postgres
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .execute(sql.postgres.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .execute(sql.postgres.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
                 return Ok(DBExecResult::from(data));
             }
@@ -937,8 +937,8 @@ impl DBPoolConn {
                 let data: SqliteQueryResult = self
                     .sqlite
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .execute(sql.sqlite.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .execute(sql.sqlite.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
                 return Ok(DBExecResult::from(data));
             }
@@ -947,8 +947,8 @@ impl DBPoolConn {
                 let data: MssqlQueryResult = self
                     .mssql
                     .as_mut()
-                    .ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?
-                    .execute(sql.mssql.ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?)
+                    .ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?
+                    .execute(sql.mssql.ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?)
                     .await?;
                 return Ok(DBExecResult::from(data));
             }
@@ -977,19 +977,19 @@ impl DBPoolConn {
             }
             #[cfg(feature = "mysql")]
             &DriverType::Mysql => {
-                return Ok(self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.ping().await?);
+                return Ok(self.mysql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.ping().await?);
             }
             #[cfg(feature = "postgres")]
             &DriverType::Postgres => {
-                return Ok(self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.ping().await?);
+                return Ok(self.postgres.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.ping().await?);
             }
             #[cfg(feature = "sqlite")]
             &DriverType::Sqlite => {
-                return Ok(self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.ping().await?);
+                return Ok(self.sqlite.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.ping().await?);
             }
             #[cfg(feature = "mssql")]
             &DriverType::Mssql => {
-                return Ok(self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core]  conn is none!"))?.ping().await?);
+                return Ok(self.mssql.as_mut().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?.ping().await?);
             }
             _ => {
                 return Err(Error::from("[rbatis] feature not enable!"));
