@@ -17,6 +17,8 @@ use crate::convert::{JsonCodec, RefJsonCodec, ResultCodec};
 use crate::postgres::PgInterval;
 use chrono::Utc;
 
+use crate::{new_json_option_into};
+
 impl<'c> JsonCodec for PgValueRef<'c> {
     fn try_to_json(self) -> crate::Result<serde_json::Value> {
         match self.type_info().name() {
@@ -26,91 +28,91 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             "NUMERIC" => {
                 //decimal
                 let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "NUMERIC[]" => {
                 //decimal
                 let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "MONEY" => {
                 //decimal
                 let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "MONEY[]" => {
                 //decimal
                 let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "BOOL" => {
                 let r: Option<bool> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "BOOL[]" => {
                 let r: Vec<bool> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(r.into());
             }
             "BYTEA" | "BYTEA[]" => {
                 let r: Option<Vec<u8>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "FLOAT4" => {
                 let r: Option<f32> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "FLOAT4[]" => {
                 let r: Option<Vec<f32>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "FLOAT8" => {
                 let r: Option<f64> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "FLOAT8[]" => {
                 let r: Option<Vec<f64>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT2" => {
                 let r: Option<i16> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT2[]" => {
                 let r: Option<Vec<i16>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT4" => {
                 let r: Option<i32> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT4[]" => {
                 let r: Option<Vec<i32>> = Decode::<'_, Postgres>::decode(self)?;
 
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT8" => {
                 let r: Option<i64> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "INT8[]" => {
                 let r: Option<Vec<i64>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "OID" => {
                 let r: Option<u32> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "OID[]" => {
                 let r: Option<Vec<u32>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "TEXT" | "NAME" | "VARCHAR" | "BPCHAR" | "CHAR" | "\"CHAR\"" | "UNKNOWN" => {
                 let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "TEXT[]" | "CHAR[]" | "VARCHAR[]" | "\"CHAR\"[]" | "NAME[]" => {
                 let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
             "UUID" => {
                 let r: Option<Uuid> = Decode::<'_, Postgres>::decode(self)?;
@@ -172,6 +174,9 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             "INTERVAL" => {
                 let r: Option<sqlx_core::postgres::types::PgInterval> =
                     Decode::<'_, Postgres>::decode(self)?;
+                if r.is_none() {
+                    return Ok(serde_json::Value::Null);
+                }
                 return Ok(json!(PgInterval::from(r.unwrap())));
             }
             "VARBIT" | "BIT" => {
@@ -205,7 +210,7 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                 // "MACADDR","MACADDR[]",
                 //  you can use already Vec<u8> types to decode this
                 let r: Option<Vec<u8>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                return Ok(new_json_option_into!(r));
             }
         }
     }
